#!/bin/bash

DIR="/home/ravioli/newdisk-automator"

. "${DIR}/error.sh"
. "${DIR}/parse-arguments.sh"

PROGRAM_NAME="$0"

DEVICE=$1
SWAP_SIZE=$2
CONDOR_SIZE=$3
TEMP_SIZE=$4
VM_SIZE=$5

fatal 2

# checking if the disk is used
if [ ! -e ${DEVICE} ] ; then
	fatal ${NOTEX_E} "${DEVICE} does not exist"
fi
if [ ! -b ${DEVICE} ] ; then
	fatal ${NOTBLK_E} "${DEVICE} is not a block file"
fi
if grep --quiet "${DEVICE}" /proc/mounts ; then
	fatal ${ISMOUNT_E} "${DEVICE} is mounted"
fi
if grep --quiet "${DEVICE}" /proc/swaps ; then
	fatal ${ISSWAP_E} "${DEVICE} is udes as swap"
fi

if pvs | grep --quiet "${DEVICE}" ; then
	if [ $(lvs --noheadings --select vg_name="$(pvs --noheadings --select pv_name=~"${DEVICE}" -o vg_name)" --select lv_device_open!=0 | wc -l) -ne 0 ] ; then
		fatal ${LVMUSED_E} "${DEVICE} is part of a used lvm volume"
	fi
	if [ $(vgs --noheadings --select pv_name=~"${DEVICE}" -o pv_count | uniq) -gt $(vgs --noheadings --select pv_name=~"${DEVICE}" | wc -l) ] ; then
		fatal ${LVMPV_E} "${DEVICE} is part of a lvm volume group shared with other physical volumes"
	fi

	# removing lvm and other filesystem signatures)
	echo "Eresing disk signatures..."
	vgchange -an $(vgs --noheadings --select pv_name=~"${DEVICE}" -o vg_name)
	wipefs -a ${DEVICE}[[:digit:]]*
	wipefs -a ${DEVICE}
fi

echo "SFDISK ----------------------------------------------------"
# partitioning the disk
sfdisk "${DEVICE}" <<-sfdisk-script-end
# Create a new partition table on the specified disk, and create a new Linux LVM partition
#
# partition table info
label: gpt
#
# partitions info
#start	size	type	bootable
,	,31	,
sfdisk-script-end

# LVM
echo "PVCREATE --------------------------------------------------"
pvcreate "${DEVICE}1"
echo "VGCREATE --------------------------------------------------"
vgcreate localDisk "${DEVICE}1"

if [ "${SWAP_SIZE}" != 0 ] ; then
	echo "LVCREATE  SWAP --------------------------------------------------"
	lvcreate -W n -C y -L "${SWAP_SIZE}G" localDisk -n swap
	echo "MKSWAP --------------------------------------------------"
	mkswap /dev/localDisk/swap
fi
if [ "${CONDOR_SIZE}" != 0 ] ; then
	echo "LVCREATE CONDOR --------------------------------------------------"
	lvcreate -W n -L "${CONDOR_SIZE}G" localDisk -n condor
	echo "MKFS CONDOR --------------------------------------------------"
	mkfs.ext4 /dev/localDisk/condor
fi
if [ "${TEMP_SIZE}" != 0 ] ; then
	echo "LVCREATE TEMP --------------------------------------------------"
	lvcreate -W n -L "${TEMP_SIZE}G" localDisk -n tempdir
	echo "MKFS TEMP --------------------------------------------------"
	mkfs.ext4 /dev/localDisk/tempdir
fi
if [ "${VM_SIZE}" != 0 ] ; then
	echo "LVCREATE CALCOLO --------------------------------------------------"
	lvcreate -W n -L "${VM_SIZE}G" localDisk -n calcolo
fi
